@@ -1,9 +1,9 @@
 from typing import Dict, List, Optional, TypeVar
 
+from grai_schemas.base import Edge, Node
+from grai_schemas.utilities import merge_models
+
 from grai_client.endpoints.client import BaseClient
-from grai_client.schemas.edge import Edge
-from grai_client.schemas.node import Node
-from grai_client.schemas.utilities import merge_models
 
 T = TypeVar("T", Node, Edge)
 
@@ -32,9 +32,7 @@ def update(client: BaseClient, items: List[T], active_items: Optional[List[T]] =
     deactivated_items = deactivate([current_item_map[k] for k in deactivated_item_keys])
     new_items: List[T] = [item_map[k] for k in new_item_keys]
     updated_items = [
-        merge_models(item_map[k], current_item_map[k])
-        for k in updated_item_keys
-        if item_map[k] != current_item_map[k]
+        merge_models(item_map[k], current_item_map[k]) for k in updated_item_keys if item_map[k] != current_item_map[k]
     ]
     client.patch(deactivated_items)
     client.patch(updated_items)
